package gcewing.prospecting;

import net.minecraft.src.*;

public class ItemMiningRadar extends Item {

	static int lastKey = 0;
	static float hitBreakChance = 0.05F;
	static int maxBatteryCharge = 18000;
	//static int iconIndex = ModLoader.addOverride("/gui/items.png", "/gcewing/prospecting/resources/mining_radar.png");
	
	public ItemMiningRadar(int id, String iconFile) {
		super(id);
		setMaxStackSize(1);
		//setMaxDamage(maxBatteryCharge);
		setIconIndex(ModLoader.addOverride("/gui/items.png", "/gcewing/prospecting/resources/" + iconFile));
		setNoRepair();
	}

	int getRange(ItemStack stack) {
		return getTagCompound(stack).getInteger("range");
	}
	
	void setRange(ItemStack stack, int value) {
		getTagCompound(stack).setInteger("range", value);
	}
	
	SignalMode getSignalMode(ItemStack stack) {
		return SignalMode.valueOf(getTagCompound(stack).getString("signalMode"));
	}
	
	void setSignalMode(ItemStack stack, SignalMode value) {
		getTagCompound(stack).setString("signalMode", value.toString());
	}
	
	static int getBatteryCharge(ItemStack stack) {
		return getTagCompound(stack).getInteger("charge");
	}
	
	static void setBatteryCharge(ItemStack stack, int value) {
		getTagCompound(stack).setInteger("charge", value);
	}
	
	static NBTTagCompound getTagCompound(ItemStack stack) {
//		System.out.printf("ItemMiningRadar: Getting tagCompound from %s\n",
//			stack.hashCode());
		NBTTagCompound tag = stack.getTagCompound();
		if (tag == null) {
			System.out.printf("ItemMiningRadar: Adding NBTTagCompound\n");
			tag = new NBTTagCompound();
			tag.setInteger("range", 5);
			tag.setString("signalMode", SignalMode.Maximum.toString());
			tag.setInteger("charge", maxBatteryCharge);
			stack.setTagCompound(tag);
			//stack.stackTagCompound = tag;
		}
		return tag;
	}

//	public ItemStack onItemRightClick(ItemStack stack, World world, EntityPlayer player) {
//		return stack;
//	}

	public void onUpdate(ItemStack stack, World world, Entity entity, int slotNum, boolean inHand) {
		//System.out.printf("ItemMiningRadar.onUpdate: slot %d in hand %s\n", slotNum, inHand);
		if (!world.isRemote) {
			if (inHand) {
				updateBattery(stack);
			}
		}
	}
	
//	void updateBattery(ItemStack stack) {
//		int d = stack.getItemDamage();
//		int m = stack.getMaxDamage();
//		if (d >= 0 && d < m) {
//			d += getRange(stack) / 5;
//			if (d > m)
//				d = m;
//			stack.setItemDamage(d);
//			//System.out.printf("ItemMiningRadar: damage = %d\n", stack.getItemDamage());
//		}
//	}
	
	void updateBattery(ItemStack stack) {
		int charge = getBatteryCharge(stack);
		charge -= getRange(stack) / 5;
		if (charge < 0)
			charge = 0;
		setBatteryCharge(stack, charge);
//		System.out.printf("ItemMiningRadar.updateBattery: charge = %d\n", charge);
	}
	
	public void performAction(ItemStack stack, MiningRadarAction action) {
		switch (action) {
			case IncreaseRange:
				increaseRange(stack);
				break;
			case DecreaseRange:
				reduceRange(stack);
				break;
			case SelectDiscriminationMode:
				setSignalMode(stack, SignalMode.Maximum);
				break;
			case SelectLinearMode:
				setSignalMode(stack, SignalMode.Sum);
				break;
		}
	}
	
	public void increaseRange(ItemStack stack) {
		int range = getRange(stack);
		if (range < 15)
			setRange(stack, range + 5);
	}
	
	public void reduceRange(ItemStack stack) {
		int range = getRange(stack);
		if (range > 5)
			setRange(stack, range - 5);
	}
	
	void makeBroken(ItemStack stack) {
		stack.itemID = GregsProspecting.brokenMiningRadar.shiftedIndex;
		stack.setTagCompound(null);
		//stack.setItemDamage(0);
	}

//	public boolean shouldRotateAroundWhenRendering() {
//		return true;
//	}

	public boolean onBlockStartBreak(ItemStack stack, int x, int y, int z, EntityPlayer player) {
		World world = player.worldObj;
		//System.out.printf("ItemMiningRadar.onBlockStartBreak\n");
		if (world.rand.nextFloat() < hitBreakChance) {
			System.out.printf("ItemMiningRadar: You've broken it!\n");
			world.playSoundEffect(x + 0.5D, y + 0.5D, z + 0.5D, "random.glass", 2.0F, world.rand.nextFloat() * 0.1F + 0.9F);
			makeBroken(stack);
		}
		return false;
	}
	
	public boolean isDamageable() {
		// This needs to be true, otherwise the NBTTagCompound is not sent
		// from the server to the client.
		return true;
	}
	
	public boolean isItemTool(ItemStack stack) {
		// ...but we don't want it to look like a tool, otherwise it will
		// be enchantable and maybe have other undesirable effects.
		return false;
	}
	
	public boolean isColor(ItemStack stack) {
		return stack.getItem() == GregsProspecting.colorMiningRadar;
	}

}
